Welcome to AiiDA-Defects
========================

AiiDA-Defects is a plugin for the [AiiDA](http://www.aiida.net/) computational materials science framework, and provides tools and automated workflows for the study of defects in materials.

The package is available for download from [GitHub](http://github.com/aiida-defects).

If you use AiiDA-Defects in your work, please cite:

*AiiDA-defects: An automated and fully reproducible workflow for the complete characterization of defect chemistry in functional materials* 
[doi.org/10.48550/arXiv.2303.12465 (preprint)](https://doi.org/10.48550/arXiv.2303.12465)

Please also remember to cite the [AiiDA paper](https://doi.org/10.1038/s41597-020-00638-4).


Quick Setup
===========

Install the latest release of this package by running the following in your shell:

    $ pip install aiida-defects

This will install all of the prerequisites automatically (including for the optional docs) 
in your environment, including AiiDA core, if it not already installed. 


Getting Started
===============

Expample usage of the workchains is documented in the collection of Jupyter notebooks in the ``examples`` directory.


Acknowledgements
================
This work is supported by the MARVEL National Centre of Competence in Research (NCCR) funded by the Swiss National Science Foundation (grant agreement ID 51NF40-182892) and by the European Union’s Horizon 2020 research and innovation program under Grant Agreement No. 824143 (European MaX Centre of Excellence “Materials design at the Exascale”) and Grant Agreement No. 814487 (INTERSECT project). We thank Chiara Ricca and Ulrich Aschauer for discussions and prototype implementation ideas. The authors also would like to thank the Swiss National Supercomputing Centre CSCS (project s1073) for providing the computational ressources and Solvay for funding this project. We thank Arsalan Akhtar, Lorenzo Bastonero, Luca Bursi, Francesco Libbi, Riccardo De Gennaro and Daniele Tomerini for useful discussions and feedback.
